@@ -306,6 +306,7 @@ class Source(ZoopObject):
         card=None,
         type="card",
         currency="BRL",
+        installment_plan=None,
         **kwargs,
     ):
         setattr(self, "type", type)
@@ -372,7 +373,9 @@ class Source(ZoopObject):
     @classmethod
     def get_required_fields(cls):
         fields = super().get_required_fields()
-        return fields.union({"card", "type", "currency", "usage", "amount"})
+        return fields.union(
+            {"card", "type", "currency", "usage", "amount", "installment_plan"}
+        )
 
     @classmethod
     def get_card_not_present_required_fields(cls):
